==> pyque-0.3.tar.gz: pyque-0.3/pyque/sh.py <==
# -*- encoding: utf-8 -*-

import os
from datetime import datetime
from subprocess import Popen, PIPE, STDOUT



def sh(cmd):
    """ Executes the given command.
    returns a 2-tuple with returncode (integer) and OUTPUT (string)
    """

    # we mimic subprocess.check_output from python 2.7
    # to stay compatible with python 2.5+

    process = Popen(cmd, stdout=PIPE, stderr=STDOUT, shell=True)
    output, unused_err = process.communicate()
    retcode = process.poll()

    return (retcode, output)


def gzip(filename):
    """ Gzip a file
    """

    infodict = {}
    anyerror = False

    infodict['starttime'] = datetime.now()

    try:
        infodict['original_filesize'] = os.path.getsize(filename)
    except OSError:
        infodict['original_filesize'] = 0
        anyerror = True

    ## run gzip
    retcode, output = sh('gzip %s' % filename)
    
    if retcode != 0: anyerror = True

    infodict['error'] = anyerror
    infodict['errortext'] = None if retcode == 0 else output

    new_filename = filename+'.gz'
    

    infodict['new_filename'] = new_filename
    infodict['endtime'] = datetime.now()

    try:
        infodict['new_filesize'] = os.path.getsize(new_filename)
    except OSError:
        infodict['new_filesize'] = 0
        anyerror = True

    return infodict

def chown(path, uid, guid, recursive=True):
    """ alternative to os.chown.
        wraps around unix chown
        example:
            chown('/tmp/test/', bob, bob)

        returns exitcode and terminal output
    """

    if recursive:
        cmd = 'chown -R %s:%s %s' % (uid, guid, path)
    else:
        cmd = 'chown %s:%s %s' % (uid, guid, path)

    return sh(cmd)

def chmod(path, mode, recursive=True):
    """ alternative to os.
    """

==> pyque-0.3.3.tar.gz: pyque-0.3.3/pyque/sh.py <==
# -*- encoding: utf-8 -*-

import os
from datetime import datetime
from subprocess import Popen, PIPE, STDOUT

def quote(s):
    """ Return a shell escaped version of a string
    """
    return '"%s"' % (s.replace('\\', '\\\\')
        .replace('"', '\"')
        .replace('$', '\$')
        .replace('`', '\`')
        )


def sh(cmd, escape=True):
    """ Executes the given command.
    returns a 2-tuple with returncode (integer) and OUTPUT (string)
    """

    # we mimic subprocess.check_output from python 2.7
    # to stay compatible with python 2.5+
    if escape:
        cmd = quote(cmd)

    print cmd

    process = Popen(cmd, stdout=PIPE, stderr=STDOUT, shell=True)
    output, unused_err = process.communicate()
    retcode = process.poll()

    return (retcode, output)


def gzip(filename):
    """ Gzip a file
    returns a 3-tuble with returncode (integer), terminal output (string)
    and the new filename.
    """

    ## run gzip
    retcode, output = sh('gzip %s' % filename)
    new_filename = filename+'.gz'

    return (retcode, output, new_filename)

def chown(path, uid, guid, recursive=True):
    """ alternative to os.chown.
        wraps around unix chown
        example:
            chown('/tmp/test/', bob, bob)

        returns 2-tuple: exitcode and terminal output
    """

    if recursive:
        cmd = 'chown -R %s:%s %s' % (uid, guid, path)
    else:
        cmd = 'chown %s:%s %s' % (uid, guid, path)

    return sh(cmd)

def chmod(path, mode, recursive=True):
    """ alternative to os.
    """

    if recursive:
        cmd = 'chmod -R %s %s' % (mode, path)
    else:
        cmd = 'chmod %s %s' % (mode, path)

    return sh(cmd)
